#undef PACKAGE
#undef VERSION
#undef HAVE_LIBSM
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef ENABLE_NLS
#undef USE_PTHREAD
#undef HAVE_SOCKET
#undef HAVE_STRUCT_LINGER
#undef HAVE_NSL
#undef HAVE_OLDER_BZIP2
#undef GNOME_PLATFORM_VERSION
#undef ENABLE_PROFILER
#undef HAVE_OPENSSL
#undef HAVE_FAM
#undef HAVE_OFF64_T
#undef GETTEXT_PACKAGE

/* Define if you have the Andrew File System.  */
#undef AFS

/* Define to use SVR4 statvfs to get filesystem type.  */
#undef FSTYPE_STATVFS

/* Define to use SVR3.2 statfs to get filesystem type.  */
#undef FSTYPE_USG_STATFS

/* Define to use AIX3 statfs to get filesystem type.  */
#undef FSTYPE_AIX_STATFS

/* Define to use 4.3BSD getmntent to get filesystem type.  */
#undef FSTYPE_MNTENT

/* Define to use 4.4BSD and OSF1 statfs to get filesystem type.  */
#undef FSTYPE_STATFS

/* Define to use Ultrix getmnt to get filesystem type.  */
#undef FSTYPE_GETMNT

#undef HAVE_GNUTLS
#undef GNUTLS_COMPAT
#undef ENABLE_IPV6
